var util = require('util');
var winston = require('winston');
var scribe = require('scribe');
var os = require('os');

var Scribe = exports.Scribe = function (options) {
  options = options || {};
  options.host = options.host || 'localhost';
  options.port = options.port || 1463;

  this.name  = 'scribe';
  this.level = options.level || 'info';
  this.category = options.category || 'winston';
  this.client = new scribe.Scribe(options.host, options.port, {autoReconnect:true});
};

util.inherits(Scribe, winston.Transport);

Scribe.prototype.log = function (level, msg, meta, callback) {
  var self = this;

  var entry = {
    timestamp: (new Date()).toISOString(),
    host: os.hostname(),
    level: level,
    message: msg, 
  };

  if (meta) {
    entry.meta = meta;
  }

  self.client.open(function(err) {
    if (err) {
      return self.emit('error', err);
    }

    self.client.send(self.category, JSON.stringify(entry));
    self.emit('logged');
  });
  return callback(null, true);
};

winston.transports.Scribe = Scribe;
